<?php
	class security_statistics_controller extends graph_controller {
		protected $graphs = array(
			"exploit_attempts"      => "Exploit attempts",
			"bans"                  => "Clients banned");
	}
?>
